@@ -4,6 +4,7 @@ from ..pyinstaller import spec
 from ..helpers import MINIMUM_ENTITLEMENTS, write_minimum_entitlements
 from ..command import Command
 from ..logger import logger
+import string
 
 
 class App:
@@ -35,6 +36,7 @@ class App:
         self._build = None
         self._dist = None
         self._app = None
+        self._url_schema = None
         # check vars
         self._built = False
         self._signed = False
@@ -47,8 +49,9 @@ class App:
         return f"App({self._name=})"
 
     def config(self, main: str, architecture: str = "universal2", entitlements: str = MINIMUM_ENTITLEMENTS,
+               hidden_imports: "list[str]" = None, collect_submodules: "list[str]" = None,
                specpath: str = os.path.abspath(os.path.dirname(__file__)), log_level: str = "WARN",
-               brute: bool = False):
+               brute: bool = False, url_schema: str = None):
         """configure the .spec file that pyinstaller uses to build the app
 
         :param main: the main script (main.py, etc.) where you run your application from
@@ -63,6 +66,8 @@ class App:
         :type log_level: str, optional
         :param brute: override built-in checks by pymacapp, defaults to False
         :type brute: bool, optional
+        :param url_schema: the prefix for a custom url schema; defaults to None (no schema)
+        :type url_schema: str, optional
         :return: self (current app)
         :rtype: App
         """
@@ -74,11 +79,45 @@ class App:
                           identifier=self._identifier,
                           architecture=architecture,
                           entitlements=entitlements,
+                          hidden_imports=hidden_imports,
+                          collect_submodules=collect_submodules,
                           specpath=specpath,
                           log_level=log_level,
                           brute=False)
         self._pyinstaller_log_level: str = log_level
         self._entitlements = entitlements
+
+        # TODO: add handling for info.plist to be added after the spec is built; CANNOT execute until it is built (inside this function)
+        if url_schema:
+            self._url_schema = url_schema
+        # app = BUNDLE(coll,
+        #              name='Flagship.app',
+        #              icon=None,
+        #              bundle_identifier='com.nicholasrbarrow.flagship')
+
+        infoplist = f"""\n             info_plist = {{
+                    'CFBundleURLTypes': [{{
+                        'CFBundleURLName': '{self._name}',
+                        'CFBundleTypeRole': 'Viewer',
+                        'CFBundleURLSchemes': ['{self._url_schema}', ],
+                    }}],
+                    'CFBundleDocumentTypes': [{{
+                        'CFBundleTypeName': '{self._name}',
+                        'CFBundleTypeExtensions': ['{self._url_schema}', ],
+                        'CFBundleTypeRole': "Viewer",
+                    }}],
+                }})"""
+
+        lines = []
+        with open(self._spec, "r") as f:
+            lines = f.readlines()
+
+        lines[-1] = lines[-1][0:lines[-1].find(")")] + ","
+
+        with open(self._spec, "w") as f:
+            f.writelines(lines)
+            f.writelines(infoplist)
+
         return self
 
     def build(self, dist_path: str = os.path.join(os.getcwd(), "dist"),
