@@ -5,8 +5,4 @@ formatter = logging.Formatter("%(asctime)s pymacapp >>> %(filename)s @ %(lineno)
 streamHandler = logging.StreamHandler()
 streamHandler.setLevel(logging.DEBUG)
 streamHandler.setFormatter(formatter)
-logger.addHandler(streamHandler)
-
-def set_level(level:int=logging.DEBUG):
-    logger.setLevel(level)
-    streamHandler.setLevel(level)
\ No newline at end of file
+logger.addHandler(streamHandler)
\ No newline at end of file
